@@ -3,7 +3,7 @@
  * CHECKS.C - Service and host check functions for Nagios
  *
  * Copyright (c) 1999-2007 Ethan Galstad (nagios@nagios.org)
- * Last Modified:   04-10-2006
+ * Last Modified:   10-19-2007
  *
  * License:
  *
@@ -679,7 +679,7 @@ void reap_service_checks(void){
 		/* calculate passive check latency */
 		if(queued_svc_msg.check_type==SERVICE_CHECK_PASSIVE){
 			gettimeofday(&tv,NULL);
-			temp_service->latency=(double)((double)(tv.tv_sec-queued_svc_msg.finish_time.tv_sec)+(double)((tv.tv_usec-queued_svc_msg.finish_time.tv_usec)/1000.0));
+			temp_service->latency=(double)((double)(tv.tv_sec-queued_svc_msg.finish_time.tv_sec)+(double)((tv.tv_usec-queued_svc_msg.finish_time.tv_usec)/1000.0/1000.0));
 			if(temp_service->latency<0.0)
 				temp_service->latency=0.0;
 		        }
@@ -1442,7 +1442,9 @@ void schedule_service_check(service *svc,time_t check_time,int forced){
 #endif
 
 	/* don't schedule a check if active checks are disabled */
-	if((execute_service_checks==FALSE || svc->checks_enabled==FALSE) && forced==FALSE)
+	/* 10/19/07 EG - schedule service checks even if they're disabled on a program-wide basis */
+	/*if((execute_service_checks==FALSE || svc->checks_enabled==FALSE) && forced==FALSE)*/
+	if(svc->checks_enabled==FALSE && forced==FALSE)
 		return;
 
 	/* allocate memory for a new event item */
