@@ -2,8 +2,8 @@
  *
  * CONFIG.C - Configuration input and verification routines for Nagios
  *
- * Copyright (c) 1999-2005 Ethan Galstad (nagios@nagios.org)
- * Last Modified:   12-26-2005
+ * Copyright (c) 1999-2007 Ethan Galstad (nagios@nagios.org)
+ * Last Modified:   01-19-2007
  *
  * License:
  *
@@ -166,6 +166,8 @@ extern serviceextinfo   *serviceextinfo_list;
 extern host		**host_hashlist;
 extern service		**service_hashlist;
 
+extern int              external_command_buffer_slots;
+extern int              check_result_buffer_slots;
 
 
 
@@ -252,16 +254,16 @@ int read_main_config_file(char *main_config_file){
 
 		current_line=thefile->current_line;
 
-		/* skip blank lines */
-		if(input[0]=='\x0' || input[0]=='\n' || input[0]=='\r')
-			continue;
-
 		strip(input);
 
 		/* skip comments */
 		if(input[0]=='#' || input[0]==';')
 			continue;
 
+		/* skip blank lines */
+		if(input[0]=='\x0' || input[0]=='\n' || input[0]=='\r')
+			continue;
+
 		/* skip external data directives */
 		if(strstr(input,"x")==input)
 			continue;
@@ -1401,6 +1403,12 @@ int read_main_config_file(char *main_config_file){
 #endif
 			}
 
+		else if(!strcmp(variable,"external_command_buffer_slots"))
+			external_command_buffer_slots=atoi(value);
+
+		else if(!strcmp(variable,"check_result_buffer_slots"))
+			check_result_buffer_slots=atoi(value);
+
 		/*** AUTH_FILE VARIABLE USED BY EMBEDDED PERL INTERPRETER ***/
 		else if(!strcmp(variable,"auth_file")){
 			if(strlen(value)>MAX_FILENAME_LENGTH-1){
