@@ -2,8 +2,8 @@
  *
  * EVENTS.C - Timed event functions for Nagios
  *
- * Copyright (c) 1999-2006 Ethan Galstad (nagios@nagios.org)
- * Last Modified:   10-09-2006
+ * Copyright (c) 1999-2007 Ethan Galstad (nagios@nagios.org)
+ * Last Modified:   03-05-2007
  *
  * License:
  *
@@ -89,6 +89,7 @@ extern service  *service_list;
 
 sched_info scheduling_info;
 
+extern unsigned long   check_result_buffer_slots;
 
 
 /******************************************************************/
@@ -643,7 +644,7 @@ void display_scheduling_info(void){
 	        }
 
 	/* assume a 100% (2x) service check burst for service check reaper */
-	max_reaper_interval=floor((double)SERVICE_BUFFER_SLOTS/scheduling_info.service_inter_check_delay);
+	max_reaper_interval=floor((double)check_result_buffer_slots/scheduling_info.service_inter_check_delay);
 	if(max_reaper_interval<2.0)
 		max_reaper_interval=2.0;
 	if(max_reaper_interval>30.0)
@@ -1287,7 +1288,11 @@ int handle_timed_event(timed_event *event){
 #endif
 
 		/* process scheduled downtime info */
-		handle_scheduled_downtime((scheduled_downtime *)event->event_data);
+		if(event->event_data){
+			handle_scheduled_downtime_by_id(*(unsigned long *)event->event_data);
+			free(event->event_data);
+			event->event_data=NULL;
+			}
 		break;
 
 	case EVENT_SFRESHNESS_CHECK:
