@@ -2,8 +2,8 @@
  *
  * NOTIFICATIONS.C - Service and host notification functions for Nagios
  *
- * Copyright (c) 1999-2006 Ethan Galstad (nagios@nagios.org)
- * Last Modified:   04-07-2006
+ * Copyright (c) 1999-2007 Ethan Galstad (nagios@nagios.org)
+ * Last Modified:   08-06-2007
  *
  * License:
  *
@@ -667,7 +667,7 @@ int notify_contact_of_service(contact *cntct, service *svc, int type, char *ack_
 
 			/* check to see if the notification command timed out */
 			if(early_timeout==TRUE){
-				snprintf(temp_buffer,sizeof(temp_buffer),"Warning: Contact '%s' service notification command '%s' timed out after %d seconds\n",cntct->name,processed_command,DEFAULT_NOTIFICATION_TIMEOUT);
+				snprintf(temp_buffer,sizeof(temp_buffer),"Warning: Contact '%s' service notification command '%s' timed out after %d seconds\n",cntct->name,processed_command,notification_timeout);
 				temp_buffer[sizeof(temp_buffer)-1]='\x0';
 				write_to_logs_and_console(temp_buffer,NSLOG_SERVICE_NOTIFICATION | NSLOG_RUNTIME_WARNING,TRUE);
 			        }
@@ -1414,7 +1414,7 @@ int notify_contact_of_host(contact *cntct, host *hst, int type, char *ack_author
 
 			/* check to see if the notification timed out */
 			if(early_timeout==TRUE){
-				snprintf(temp_buffer,sizeof(temp_buffer),"Warning: Contact '%s' host notification command '%s' timed out after %d seconds\n",cntct->name,processed_command,DEFAULT_NOTIFICATION_TIMEOUT);
+				snprintf(temp_buffer,sizeof(temp_buffer),"Warning: Contact '%s' host notification command '%s' timed out after %d seconds\n",cntct->name,processed_command,notification_timeout);
 				temp_buffer[sizeof(temp_buffer)-1]='\x0';
 				write_to_logs_and_console(temp_buffer,NSLOG_HOST_NOTIFICATION | NSLOG_RUNTIME_WARNING,TRUE);
 			        }
@@ -1637,7 +1637,7 @@ time_t get_next_service_notification_time(service *svc, time_t offset){
 
 		/* else use the shortest of all valid escalation intervals */
 		else if(temp_se->notification_interval<interval_to_use)
-			interval_to_use=svc->notification_interval;
+			interval_to_use=temp_se->notification_interval;
 #ifdef DEBUG4
 		printf("\t\tNew interval: %d\n",interval_to_use);
 #endif
