@@ -3,7 +3,7 @@
  * CGIUTILS.C - Common utilities for Nagios CGIs
  * 
  * Copyright (c) 1999-2007 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 04-10-2007
+ * Last Modified: 11-10-2007
  *
  * License:
  *
@@ -1345,7 +1345,7 @@ char * url_encode(char *input){
 char * html_encode(char *input){
 	int len,output_len;
 	int x,y;
-	char temp_expansion[7];
+	char temp_expansion[10];
 
 	len=(int)strlen(input);
 	output_len=(int)sizeof(encoded_html_string);
@@ -1399,7 +1399,7 @@ char * html_encode(char *input){
 		/* for simplicity, everything else gets represented by its numeric value */
 		else{
 			encoded_html_string[y]='\x0';
-			sprintf(temp_expansion,"&#%d;",(unsigned int)input[x]);
+			sprintf(temp_expansion,"&#%d;",(unsigned char)input[x]);
 			if((int)strlen(encoded_html_string)<(output_len-strlen(temp_expansion))){
 				strcat(encoded_html_string,temp_expansion);
 				y+=strlen(temp_expansion);
@@ -1414,12 +1414,26 @@ char * html_encode(char *input){
 
 
 
-/* strips dangerous HTML from plugin output */
-char * strip_plugin_html(char *input){
 
-	/* TODO */
+/* strip > and < from string */
+void strip_html_brackets(char *buffer){
+	register int x;
+	register int y;
+	register int z;
 
-	return input;
+	if(buffer==NULL || buffer[0]=='\x0')
+		return;
+
+	/* remove all occurances in string */
+	z=(int)strlen(buffer);
+	for(x=0,y=0;x<z;x++){
+		if(buffer[x]=='<' || buffer[x]=='>')
+			continue;
+		buffer[y++]=buffer[x];
+	        }
+	buffer[y++]='\x0';
+
+	return;
 	}
 
 
@@ -1604,7 +1618,7 @@ void display_info_table(char *title,int refresh, authdata *current_authdata){
 	if(refresh==TRUE)
 		printf("Updated every %d seconds<br>\n",refresh_rate);
 
-	printf("Nagios&reg; - <A HREF='http://www.nagios.org' TARGET='_new' CLASS='homepageURL'>www.nagios.org</A><BR>\n");
+	printf("Nagios&reg; %s - <A HREF='http://www.nagios.org' TARGET='_new' CLASS='homepageURL'>www.nagios.org</A><BR>\n",PROGRAM_VERSION);
 
 	if(current_authdata!=NULL)
 		printf("Logged in as <i>%s</i><BR>\n",(!strcmp(current_authdata->username,""))?"?":current_authdata->username);
