@@ -2,14 +2,14 @@
  *
  * GETCGI.C -  Nagios CGI Input Routines
  *
- * Last Modified: 04-12-2006
+ * Last Modified: 05-15-2006
  *
  *****************************************/
 
-#include "../common/config.h"
+#include "../include/config.h"
+#include "../include/getcgi.h"
 #include <stdio.h>
 #include <stdlib.h>
-#include "getcgi.h"
 
 
 #undef PARANOID_CGI_INPUT
@@ -21,6 +21,9 @@ void sanitize_cgi_input(char **cgivars){
 	int x,y,i;
 	int keep;
 
+	/* don't strip for now... */
+	return;
+
 	for(strptr=cgivars[i=0];strptr!=NULL;strptr=cgivars[++i]){
 
 		for(x=0,y=0;strptr[x]!='\x0';x++){
@@ -146,7 +149,7 @@ char **getcgivars(void){
 
 	else if(!strcmp(request_method,"POST") || !strcmp(request_method,"PUT")){
 
-		/* if CONTENT_TYPE variable is not specified, RFC-2068 says we should assume it is "application/octect-string" */
+		/* if CONTENT_TYPE variable is not specified, RFC-2068 says we should assume it is "application/octet-string" */
 		/* mobile (WAP) stations generate CONTENT_TYPE with charset, we we should only check first 33 chars */
 
 		content_type=getenv("CONTENT_TYPE");
@@ -166,8 +169,13 @@ char **getcgivars(void){
 			printf("getcgivars(): No Content-Length was sent with the POST request.\n") ;
 			exit(1);
 		        }
-		if(content_length<0)
-			content_length=0;
+
+		/* suspicious content length */
+		if((content_length<0) || (content_length>=INT_MAX-1)){
+			printf("getcgivars(): Suspicious Content-Length was sent with the POST request.\n");
+			exit(1);
+			}
+
 		if(!(cgiinput=(char *)malloc(content_length+1))){
 			printf("getcgivars(): Could not allocate memory for CGI input.\n");
 			exit(1);
