@@ -2,8 +2,8 @@
  *
  * HISTOGRAM.C -  Nagios Alert Histogram CGI
  *
- * Copyright (c) 2001-2006 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 03-21-2006
+ * Copyright (c) 2001-2007 Ethan Galstad (nagios@nagios.org)
+ * Last Modified: 10-21-2007
  *
  * License:
  * 
@@ -1086,6 +1086,7 @@ int process_cgivars(void){
 				host_name="";
 			else
 				strcpy(host_name,variables[x]);
+			strip_html_brackets(host_name);
 
 			display_type=DISPLAY_HOST_HISTOGRAM;
 		        }
@@ -1103,6 +1104,7 @@ int process_cgivars(void){
 				svc_description="";
 			else
 				strcpy(svc_description,variables[x]);
+			strip_html_brackets(svc_description);
 
 			display_type=DISPLAY_SERVICE_HISTOGRAM;
 		        }
