@@ -2,8 +2,8 @@
  *
  * STATUSWML.C -  Nagios Status CGI for WAP-enabled devices
  *
- * Copyright (c) 2001-2006 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 03-22-2006
+ * Copyright (c) 2001-2007 Ethan Galstad (nagios@nagios.org)
+ * Last Modified: 10-21-2007
  *
  * License:
  * 
@@ -239,6 +239,7 @@ int process_cgivars(void){
 				hostgroup_name="";
 			else
 				strcpy(hostgroup_name,variables[x]);
+			strip_html_brackets(hostgroup_name);
 
 			if(!strcmp(hostgroup_name,"all"))
 				show_all_hostgroups=TRUE;
@@ -260,6 +261,7 @@ int process_cgivars(void){
 				host_name="";
 			else
 				strcpy(host_name,variables[x]);
+			strip_html_brackets(host_name);
 		        }
 
 		/* we found the service argument */
@@ -276,6 +278,7 @@ int process_cgivars(void){
 				service_desc="";
 			else
 				strcpy(service_desc,variables[x]);
+			strip_html_brackets(service_desc);
 		        }
 
 
@@ -317,6 +320,7 @@ int process_cgivars(void){
 				ping_address="";
 			else
 				strcpy(ping_address,variables[x]);
+			strip_html_brackets(ping_address);
 		        }
 
 		/* we found the traceroute argument */
@@ -333,6 +337,7 @@ int process_cgivars(void){
 				traceroute_address="";
 			else
 				strcpy(traceroute_address,variables[x]);
+			strip_html_brackets(traceroute_address);
 		        }
 
 	        }
@@ -1156,7 +1161,7 @@ void display_service(void){
 		printf("<b><anchor title='Enable Checks'>Enable Checks<go href='%s' method='post'><postfield name='host' value='%s'/><postfield name='service' value='%s'/><postfield name='cmd_typ' value='%d'/><postfield name='cmd_mod' value='%d'/><postfield name='content' value='wml'/></go></anchor></b><br/>\n",COMMAND_CGI,host_name,service_desc,CMD_ENABLE_SVC_CHECK,CMDMODE_COMMIT);
 	else{
 		printf("<b><anchor title='Disable Checks'>Disable Checks<go href='%s' method='post'><postfield name='host' value='%s'/><postfield name='service' value='%s'/><postfield name='cmd_typ' value='%d'/><postfield name='cmd_mod' value='%d'/><postfield name='content' value='wml'/></go></anchor></b><br/>\n",COMMAND_CGI,host_name,service_desc,CMD_DISABLE_SVC_CHECK,CMDMODE_COMMIT);
-		printf("<b><anchor title='Schedule Immediate Check'>Schedule Immediate Check<go href='%s' method='post'><postfield name='host' value='%s'/><postfield name='service' value='%s'/><postfield name='cmd_typ' value='%d'/><postfield name='cmd_mod' value='%d'/><postfield name='content' value='wml'/></go></anchor></b><br/>\n",COMMAND_CGI,host_name,service_desc,CMD_SCHEDULE_SVC_CHECK,CMDMODE_COMMIT);
+		printf("<b><anchor title='Schedule Immediate Check'>Schedule Immediate Check<go href='%s' method='post'><postfield name='host' value='%s'/><postfield name='service' value='%s'/><postfield name='start_time' value='%lu'/><postfield name='cmd_typ' value='%d'/><postfield name='cmd_mod' value='%d'/><postfield name='content' value='wml'/></go></anchor></b><br/>\n",COMMAND_CGI,host_name,service_desc,(unsigned long)current_time,CMD_SCHEDULE_SVC_CHECK,CMDMODE_COMMIT);
 	        }
 
 	if(temp_servicestatus->notifications_enabled==FALSE)
