@@ -2,8 +2,8 @@
  *
  * TAC.C - Nagios Tactical Monitoring Overview CGI
  *
- * Copyright (c) 2001-2004 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 11-05-2004
+ * Copyright (c) 2001-2006 Ethan Galstad (nagios@nagios.org)
+ * Last Modified: 08-22-2006
  *
  * This CGI program will display the contents of the Nagios
  * log file.
@@ -285,8 +285,13 @@ int main(void){
 		sound=service_warning_sound;
 	else if(services_unknown_unacknowledged==0 && services_warning_unacknowledged==0 && services_critical_unacknowledged==0 && hosts_down_unacknowledged==0 && hosts_unreachable_unacknowledged==0 && normal_sound!=NULL)
 		sound=normal_sound;
-	if(sound!=NULL)
-		printf("<EMBED SRC='%s%s' HIDDEN=TRUE AUTOSTART=TRUE>",url_media_path,sound);
+	if(sound!=NULL){
+		printf("<object type=\"application/x-mplayer2\" height=\"-\" width=\"0\">");
+		printf("<param name=\"filename\" value=\"%s%s\">",url_media_path,sound);
+		printf("<param name=\"autostart\" value=\"1\">");
+		printf("<param name=\"playcount\" value=\"1\">");
+		printf("</object>");
+		}
 
 
 	/**** display main tac screen ****/
@@ -311,19 +316,19 @@ void document_header(int use_stylesheet){
 	time_t current_time;
 	time_t expire_time;
 
-	printf("Cache-Control: no-store\n");
-	printf("Pragma: no-cache\n");
-	printf("Refresh: %d\n",refresh_rate);
+	printf("Cache-Control: no-store\r\n");
+	printf("Pragma: no-cache\r\n");
+	printf("Refresh: %d\r\n",refresh_rate);
 
 	time(&current_time);
 	get_time_string(&current_time,date_time,(int)sizeof(date_time),HTTP_DATE_TIME);
-	printf("Last-Modified: %s\n",date_time);
+	printf("Last-Modified: %s\r\n",date_time);
 
 	expire_time=(time_t)0L;
 	get_time_string(&expire_time,date_time,(int)sizeof(date_time),HTTP_DATE_TIME);
-	printf("Expires: %s\n",date_time);
+	printf("Expires: %s\r\n",date_time);
 
-	printf("Content-type: text/html\n\n");
+	printf("Content-type: text/html\r\n\r\n");
 
 	if(embedded==TRUE)
 		return;
