@@ -2,8 +2,8 @@
  *
  * DOWNTIME.C - Scheduled downtime functions for Nagios
  *
- * Copyright (c) 2000-2005 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 08-01-2005
+ * Copyright (c) 2000-2007 Ethan Galstad (nagios@nagios.org)
+ * Last Modified: 03-05-2007
  *
  * License:
  *
@@ -118,7 +118,6 @@ int schedule_downtime(int type, char *host_name, char *service_description, time
 /* unschedules a host or service downtime */
 int unschedule_downtime(int type,unsigned long downtime_id){
 	scheduled_downtime *temp_downtime;
-	scheduled_downtime *event_downtime;
 	host *hst=NULL;
 	service *svc=NULL;
 	timed_event *temp_event;
@@ -193,10 +192,7 @@ int unschedule_downtime(int type,unsigned long downtime_id){
 	for(temp_event=event_list_high;temp_event!=NULL;temp_event=temp_event->next){
 		if(temp_event->event_type!=EVENT_SCHEDULED_DOWNTIME)
 			continue;
-		event_downtime=(scheduled_downtime *)temp_event->event_data;
-		if(event_downtime->type!=temp_downtime->type)
-			continue;
-		if(event_downtime->downtime_id==downtime_id)
+		if(((unsigned long)temp_event->event_data)==downtime_id)
 			break;
 	        }
 	if(temp_event!=NULL)
@@ -209,10 +205,18 @@ int unschedule_downtime(int type,unsigned long downtime_id){
 		delete_service_downtime(downtime_id);
 
 	/* unschedule all downtime entries that were triggered by this one */
-	for(temp_downtime=scheduled_downtime_list;temp_downtime!=NULL;temp_downtime=temp_downtime->next){
-		if(temp_downtime->triggered_by==downtime_id)
-			unschedule_downtime(ANY_DOWNTIME,temp_downtime->downtime_id);
-	        }
+	while(1){
+
+		for(temp_downtime=scheduled_downtime_list;temp_downtime!=NULL;temp_downtime=temp_downtime->next){
+			if(temp_downtime->triggered_by==downtime_id){
+				unschedule_downtime(ANY_DOWNTIME,temp_downtime->downtime_id);
+				break;
+				}
+			}
+
+		if(temp_downtime==NULL)
+			break;
+		}
 
 	return OK;
         }
@@ -230,6 +234,7 @@ int register_downtime(int type, unsigned long downtime_id){
 	char *type_string="";
 	int hours;
 	int minutes;
+	unsigned long *new_downtime_id=NULL;
 
 	/* find the downtime entry in memory */
 	temp_downtime=find_downtime(type,downtime_id);
@@ -276,13 +281,32 @@ int register_downtime(int type, unsigned long downtime_id){
 	/*** SCHEDULE DOWNTIME - FLEXIBLE (NON-FIXED) DOWNTIME IS HANDLED AT A LATER POINT ***/
 
 	/* only non-triggered downtime is scheduled... */
-	if(temp_downtime->triggered_by==0)
-		schedule_new_event(EVENT_SCHEDULED_DOWNTIME,TRUE,temp_downtime->start_time,FALSE,0,NULL,FALSE,(void *)temp_downtime,NULL);
+	if(temp_downtime->triggered_by==0){
+		if((new_downtime_id=(unsigned long *)malloc(sizeof(unsigned long *)))){
+			*new_downtime_id=downtime_id;
+			schedule_new_event(EVENT_SCHEDULED_DOWNTIME,TRUE,temp_downtime->start_time,FALSE,0,NULL,FALSE,(void *)new_downtime_id,NULL);
+			}
+		}
 
 	return OK;
         }
 
 
+
+/* handles scheduled downtime (id passed from timed event queue) */
+int handle_scheduled_downtime_by_id(unsigned long downtime_id){
+	scheduled_downtime *temp_downtime=NULL;
+
+	/* find the downtime entry */
+	if((temp_downtime=find_downtime(ANY_DOWNTIME,downtime_id))==NULL)
+		return ERROR;
+
+	/* handle the downtime */
+	return handle_scheduled_downtime(temp_downtime);
+	}
+	
+
+
 /* handles scheduled host or service downtime */
 int handle_scheduled_downtime(scheduled_downtime *temp_downtime){
  	char buffer[MAX_INPUT_BUFFER];
@@ -290,6 +314,7 @@ int handle_scheduled_downtime(scheduled_downtime *temp_downtime){
 	host *hst=NULL;
 	service *svc=NULL;
 	time_t event_time;
+	unsigned long *new_downtime_id=NULL;
 #ifdef USE_EVENT_BROKER
 	int attr;
 #endif
@@ -389,17 +414,26 @@ int handle_scheduled_downtime(scheduled_downtime *temp_downtime){
 			        }
 		        }
 
+		/* handle (stop) downtime that is triggered by this one */
+		while(1){
+
+			/* list contents might change by recursive calls, so we use this inefficient method to prevent segfaults */
+			for(this_downtime=scheduled_downtime_list;this_downtime!=NULL;this_downtime=this_downtime->next){
+				if(this_downtime->triggered_by==temp_downtime->downtime_id){
+					handle_scheduled_downtime(this_downtime);
+					break;
+					}
+				}
+
+			if(this_downtime==NULL)
+				break;
+			}
+
 		/* delete downtime entry from the log */
 		if(temp_downtime->type==HOST_DOWNTIME)
 			delete_host_downtime(temp_downtime->downtime_id);
 		else
 			delete_service_downtime(temp_downtime->downtime_id);
-
-		/* handle (stop) downtime that is triggered by this one */
-		for(this_downtime=scheduled_downtime_list;this_downtime!=NULL;this_downtime=this_downtime->next){
-			if(this_downtime->triggered_by==temp_downtime->downtime_id)
-				handle_scheduled_downtime(this_downtime);
-		        }
 	        }
 
 	/* else we are just starting the scheduled downtime */
@@ -446,7 +480,10 @@ int handle_scheduled_downtime(scheduled_downtime *temp_downtime){
 			event_time=(time_t)((unsigned long)time(NULL)+temp_downtime->duration);
 		else
 			event_time=temp_downtime->end_time;
-		schedule_new_event(EVENT_SCHEDULED_DOWNTIME,TRUE,event_time,FALSE,0,NULL,FALSE,(void *)temp_downtime,NULL);
+		if((new_downtime_id=(unsigned long *)malloc(sizeof(unsigned long *)))){
+			*new_downtime_id=temp_downtime->downtime_id;
+			schedule_new_event(EVENT_SCHEDULED_DOWNTIME,TRUE,event_time,FALSE,0,NULL,FALSE,(void *)new_downtime_id,NULL);
+			}
 
 		/* handle (start) downtime that is triggered by this one */
 		for(this_downtime=scheduled_downtime_list;this_downtime!=NULL;this_downtime=this_downtime->next){
@@ -827,6 +864,10 @@ int add_downtime(int downtime_type, char *host_name, char *svc_description, time
 	if(triggered_by>0  && find_downtime(ANY_DOWNTIME,triggered_by)==NULL)
 		return ERROR;
 
+	/* we don't have enough info */
+	if(host_name==NULL || (downtime_type==SERVICE_DOWNTIME && svc_description==NULL))
+		return ERROR;
+
 	/* allocate memory for the downtime */
 	new_downtime=(scheduled_downtime *)malloc(sizeof(scheduled_downtime));
 	if(new_downtime==NULL)
